@@ -42,13 +42,13 @@ class FuncDecl : public Decl
 	{
 public:
 	FuncDecl(Function* function);
-	~FuncDecl();
+	~FuncDecl() override;
 
 	Function* function() const { return function_; }
 
-	void Prepare();
-	void GenForwardDeclaration(Output* out_h);
-	void GenCode(Output* out_h, Output* out_cc);
+	void Prepare() override;
+	void GenForwardDeclaration(Output* out_h) override;
+	void GenCode(Output* out_h, Output* out_cc) override;
 
 private:
 	Function* function_;
