@@ -9,6 +9,7 @@
 #include "zeek/Var.h"
 #include "zeek/broker/Data.h"
 #include "zeek/broker/Manager.h"
+#include "zeek/telemetry/Manager.h"
 
 namespace zeek
 	{
@@ -51,9 +52,18 @@ void EventHandler::SetFunc(FuncPtr f)
 	local = std::move(f);
 	}
 
-void EventHandler::Call(Args* vl, bool no_remote)
+void EventHandler::Call(Args* vl, bool no_remote, double ts)
 	{
-	call_count++;
+	if ( ! call_count )
+		{
+		static auto eh_invocations_family = telemetry_mgr->CounterFamily(
+			"zeek", "event-handler-invocations", {"name"},
+			"Number of times the given event handler was called", "1", true);
+
+		call_count = eh_invocations_family.GetOrAdd({{"name", name}});
+		}
+
+	call_count->Inc();
 
 	if ( new_event )
 		NewEvent(vl);
@@ -90,10 +100,10 @@ void EventHandler::Call(Args* vl, bool no_remote)
 					++it;
 
 					if ( it != auto_publish.end() )
-						broker_mgr->PublishEvent(topic, Name(), xs);
+						broker_mgr->PublishEvent(topic, Name(), xs, ts);
 					else
 						{
-						broker_mgr->PublishEvent(topic, Name(), std::move(xs));
+						broker_mgr->PublishEvent(topic, Name(), std::move(xs), ts);
 						break;
 						}
 					}
