@@ -157,6 +157,13 @@ public:
 	 */
 	Frame* Clone() const;
 
+	/**
+	 * Creates a copy of the frame that just includes its trigger context.
+	 *
+	 * @return a partial copy of this frame.
+	 */
+	Frame* CloneForTrigger() const;
+
 	/**
 	 * Serializes the frame in support of copy semantics for lambdas:
 	 *
@@ -200,7 +207,6 @@ public:
 	void SetTriggerAssoc(const void* arg_assoc) { assoc = arg_assoc; }
 	const void* GetTriggerAssoc() const { return assoc; }
 
-	void SetCallLoc(const Location* loc) { call_loc = loc; }
 	const detail::Location* GetCallLocation() const;
 
 	void SetDelayed() { delayed = true; }
@@ -254,7 +260,6 @@ private:
 	trigger::TriggerPtr trigger;
 	const CallExpr* call = nullptr;
 	const void* assoc = nullptr;
-	const Location* call_loc = nullptr; // only needed if call is nil
 	};
 
 	} // namespace detail
