@@ -262,6 +262,12 @@ void Manager::InitPostScript()
 	zeek_table_db_directory =
 		get_option("Broker::table_store_db_directory")->AsString()->CheckString();
 
+	// If Zeek's forwarding of network time to wallclock time was disabled,
+	// assume that also Broker does not use realtime and instead receives
+	// time via explicit AdvanceTime() calls.
+	if ( ! get_option("allow_network_time_forward")->AsBool() )
+		use_real_time = false;
+
 	detail::opaque_of_data_type = make_intrusive<OpaqueType>("Broker::Data");
 	detail::opaque_of_set_iterator = make_intrusive<OpaqueType>("Broker::SetIterator");
 	detail::opaque_of_table_iterator = make_intrusive<OpaqueType>("Broker::TableIterator");
@@ -528,7 +534,7 @@ void Manager::FlushPendingQueries()
 			while ( ! s.second->proxy.mailbox().empty() )
 				{
 				auto response = s.second->proxy.receive();
-				ProcessStoreResponse(s.second, move(response));
+				ProcessStoreResponse(s.second, std::move(response));
 				}
 			}
 		}
@@ -637,7 +643,7 @@ std::string Manager::NodeID() const
 	return to_string(bstate->endpoint.node_id());
 	}
 
-bool Manager::PublishEvent(string topic, std::string name, broker::vector args)
+bool Manager::PublishEvent(string topic, std::string name, broker::vector args, double ts)
 	{
 	if ( bstate->endpoint.is_shutdown() )
 		return true;
@@ -646,8 +652,8 @@ bool Manager::PublishEvent(string topic, std::string name, broker::vector args)
 		return true;
 
 	DBG_LOG(DBG_BROKER, "Publishing event: %s", RenderEvent(topic, name, args).c_str());
-	broker::zeek::Event ev(std::move(name), std::move(args));
-	bstate->endpoint.publish(move(topic), ev.move_data());
+	broker::zeek::Event ev(std::move(name), std::move(args), broker::to_timestamp(ts));
+	bstate->endpoint.publish(std::move(topic), ev.move_data());
 	++statistics.num_events_outgoing;
 	return true;
 	}
@@ -675,7 +681,10 @@ bool Manager::PublishEvent(string topic, RecordVal* args)
 		xs.emplace_back(data_val->data);
 		}
 
-	return PublishEvent(std::move(topic), event_name, std::move(xs));
+	// At this point we come from script-land. This means that publishing of the event was
+	// explicitly triggered. Hence, the timestamp is set to the current network time. This also
+	// means that timestamping cannot be manipulated from script-land for now.
+	return PublishEvent(std::move(topic), event_name, std::move(xs), run_state::network_time);
 	}
 
 bool Manager::PublishIdentifier(std::string topic, std::string id)
@@ -707,9 +716,9 @@ bool Manager::PublishIdentifier(std::string topic, std::string id)
 		return false;
 		}
 
-	broker::zeek::IdentifierUpdate msg(move(id), move(*data));
+	broker::zeek::IdentifierUpdate msg(std::move(id), std::move(*data));
 	DBG_LOG(DBG_BROKER, "Publishing id-update: %s", RenderMessage(topic, msg.as_data()).c_str());
-	bstate->endpoint.publish(move(topic), msg.move_data());
+	bstate->endpoint.publish(std::move(topic), msg.move_data());
 	++statistics.num_ids_outgoing;
 	return true;
 	}
@@ -729,7 +738,8 @@ bool Manager::PublishLogCreate(EnumVal* stream, EnumVal* writer,
 
 	if ( ! stream_id )
 		{
-		reporter->Error("Failed to remotely log: stream %d doesn't have name", stream->AsEnum());
+		reporter->Error("Failed to remotely log: stream %" PRId64 " doesn't have name",
+		                stream->AsEnum());
 		return false;
 		}
 
@@ -737,7 +747,8 @@ bool Manager::PublishLogCreate(EnumVal* stream, EnumVal* writer,
 
 	if ( ! writer_id )
 		{
-		reporter->Error("Failed to remotely log: writer %d doesn't have name", writer->AsEnum());
+		reporter->Error("Failed to remotely log: writer %" PRId64 " doesn't have name",
+		                writer->AsEnum());
 		return false;
 		}
 
@@ -749,23 +760,23 @@ bool Manager::PublishLogCreate(EnumVal* stream, EnumVal* writer,
 	for ( auto i = 0; i < num_fields; ++i )
 		{
 		auto field_data = detail::threading_field_to_data(fields[i]);
-		fields_data.push_back(move(field_data));
+		fields_data.push_back(std::move(field_data));
 		}
 
 	std::string topic = default_log_topic_prefix + stream_id;
-	auto bstream_id = broker::enum_value(move(stream_id));
-	auto bwriter_id = broker::enum_value(move(writer_id));
-	broker::zeek::LogCreate msg(move(bstream_id), move(bwriter_id), move(writer_info),
-	                            move(fields_data));
+	auto bstream_id = broker::enum_value(std::move(stream_id));
+	auto bwriter_id = broker::enum_value(std::move(writer_id));
+	broker::zeek::LogCreate msg(std::move(bstream_id), std::move(bwriter_id),
+	                            std::move(writer_info), std::move(fields_data));
 
 	DBG_LOG(DBG_BROKER, "Publishing log creation: %s", RenderMessage(topic, msg.as_data()).c_str());
 
 	if ( peer.node != NoPeer.node )
 		// Direct message.
-		bstate->endpoint.publish(peer, move(topic), msg.move_data());
+		bstate->endpoint.publish(peer, std::move(topic), msg.move_data());
 	else
 		// Broadcast.
-		bstate->endpoint.publish(move(topic), msg.move_data());
+		bstate->endpoint.publish(std::move(topic), msg.move_data());
 
 	return true;
 	}
@@ -784,7 +795,8 @@ bool Manager::PublishLogWrite(EnumVal* stream, EnumVal* writer, string path, int
 
 	if ( ! stream_id )
 		{
-		reporter->Error("Failed to remotely log: stream %d doesn't have name", stream->AsEnum());
+		reporter->Error("Failed to remotely log: stream %" PRId64 " doesn't have name",
+		                stream->AsEnum());
 		return false;
 		}
 
@@ -792,7 +804,8 @@ bool Manager::PublishLogWrite(EnumVal* stream, EnumVal* writer, string path, int
 
 	if ( ! writer_id )
 		{
-		reporter->Error("Failed to remotely log: writer %d doesn't have name", writer->AsEnum());
+		reporter->Error("Failed to remotely log: writer %" PRId64 " doesn't have name",
+		                writer->AsEnum());
 		return false;
 		}
 
@@ -838,9 +851,10 @@ bool Manager::PublishLogWrite(EnumVal* stream, EnumVal* writer, string path, int
 
 	std::string topic = v->AsString()->CheckString();
 
-	auto bstream_id = broker::enum_value(move(stream_id));
-	auto bwriter_id = broker::enum_value(move(writer_id));
-	broker::zeek::LogWrite msg(move(bstream_id), move(bwriter_id), move(path), move(serial_data));
+	auto bstream_id = broker::enum_value(std::move(stream_id));
+	auto bwriter_id = broker::enum_value(std::move(writer_id));
+	broker::zeek::LogWrite msg(std::move(bstream_id), std::move(bwriter_id), std::move(path),
+	                           std::move(serial_data));
 
 	DBG_LOG(DBG_BROKER, "Buffering log record: %s", RenderMessage(topic, msg.as_data()).c_str());
 
@@ -932,7 +946,7 @@ bool Manager::AutoPublishEvent(string topic, Val* event)
 
 	DBG_LOG(DBG_BROKER, "Enabling auto-publishing of event %s to topic %s", handler->Name(),
 	        topic.c_str());
-	handler->AutoPublish(move(topic));
+	handler->AutoPublish(std::move(topic));
 
 	return true;
 	}
@@ -1136,11 +1150,6 @@ void Manager::DispatchMessage(const broker::topic& topic, broker::data msg)
 
 void Manager::Process()
 	{
-	// Ensure that time gets update before processing broker messages, or events
-	// based on them might get scheduled wrong.
-	if ( use_real_time )
-		run_state::detail::update_network_time(util::current_time());
-
 	auto messages = bstate->subscriber.poll();
 
 	bool had_input = ! messages.empty();
@@ -1210,18 +1219,9 @@ void Manager::Process()
 			auto responses = s.second->proxy.receive(num_available);
 
 			for ( auto& r : responses )
-				ProcessStoreResponse(s.second, move(r));
+				ProcessStoreResponse(s.second, std::move(r));
 			}
 		}
-
-	if ( had_input )
-		{
-		if ( run_state::network_time == 0 )
-			// If we're getting Broker messages, but still haven't initialized
-			// run_state::network_time, may as well do so now because otherwise the
-			// broker/cluster logs will end up using timestamp 0.
-			run_state::detail::update_network_time(util::current_time());
-		}
 	}
 
 void Manager::ProcessStoreEventInsertUpdate(const TableValPtr& table, const std::string& store_id,
@@ -1389,8 +1389,15 @@ void Manager::ProcessEvent(const broker::topic& topic, broker::zeek::Event ev)
 
 	auto name = std::move(ev.name());
 	auto args = std::move(ev.args());
+	double ts;
 
-	DBG_LOG(DBG_BROKER, "Process event: %s %s", name.data(), RenderMessage(args).data());
+	if ( auto ev_ts = ev.ts() )
+		broker::convert(*ev_ts, ts);
+	else
+		// Default to current network time, if the received event did not contain a timestamp.
+		ts = run_state::network_time;
+
+	DBG_LOG(DBG_BROKER, "Process event: %s (%.6f) %s", name.data(), ts, RenderMessage(args).data());
 	++statistics.num_events_incoming;
 	auto handler = event_registry->Lookup(name);
 
@@ -1472,7 +1479,7 @@ void Manager::ProcessEvent(const broker::topic& topic, broker::zeek::Event ev)
 		}
 
 	if ( vl.size() == args.size() )
-		event_mgr.Enqueue(handler, std::move(vl), util::detail::SOURCE_BROKER);
+		event_mgr.Enqueue(handler, std::move(vl), util::detail::SOURCE_BROKER, 0, nullptr, ts);
 	}
 
 bool Manager::ProcessLogCreate(broker::zeek::LogCreate lc)
@@ -1864,7 +1871,7 @@ detail::StoreHandleVal* Manager::MakeMaster(const string& name, broker::backend
 		it->second = name + suffix;
 		}
 
-	auto result = bstate->endpoint.attach_master(name, type, move(opts));
+	auto result = bstate->endpoint.attach_master(name, type, std::move(opts));
 	if ( ! result )
 		{
 		Error("Failed to attach master store %s:", to_string(result.error()).c_str());
